# -*- perl -*-

# t/001_load.t - check module loading and create testing directory

use Test::More tests => 156;

BEGIN
{
	use_ok( 'Net::API::Stripe' );
	use_ok( 'Net::API::Stripe::Address' );
	use_ok( 'Net::API::Stripe::AddressKana' );
	use_ok( 'Net::API::Stripe::AddressKanji' );
	use_ok( 'Net::API::Stripe::Balance::ConnectReserved' );
	use_ok( 'Net::API::Stripe::Balance::Pending' );
	use_ok( 'Net::API::Stripe::Balance::Transaction::FeeDetails' );
	use_ok( 'Net::API::Stripe::Balance::Transaction' );
	use_ok( 'Net::API::Stripe::Balance' );
	use_ok( 'Net::API::Stripe::Billing::Coupon' );
	use_ok( 'Net::API::Stripe::Billing::CreditNote::LineItem' );
	use_ok( 'Net::API::Stripe::Billing::CreditNote' );
	use_ok( 'Net::API::Stripe::Billing::Details' );
	use_ok( 'Net::API::Stripe::Billing::Discount' );
	use_ok( 'Net::API::Stripe::Billing::Invoice::BalanceSettings' );
	use_ok( 'Net::API::Stripe::Billing::Invoice::Item' );
	use_ok( 'Net::API::Stripe::Billing::Invoice::LineItem' );
	use_ok( 'Net::API::Stripe::Billing::Invoice::Lines' );
	use_ok( 'Net::API::Stripe::Billing::Invoice::Period' );
	use_ok( 'Net::API::Stripe::Billing::Invoice::Settings' );
	use_ok( 'Net::API::Stripe::Billing::Invoice::StatusTransition' );
	use_ok( 'Net::API::Stripe::Billing::Invoice::TaxAmount' );
	use_ok( 'Net::API::Stripe::Billing::Invoice' );
	use_ok( 'Net::API::Stripe::Billing::Plan::Tiers' );
	use_ok( 'Net::API::Stripe::Billing::Plan::TransformUsage' );
	use_ok( 'Net::API::Stripe::Billing::Plan' );
	use_ok( 'Net::API::Stripe::Billing::Subscription::Item' );
	use_ok( 'Net::API::Stripe::Billing::Subscription::Items' );
	use_ok( 'Net::API::Stripe::Billing::Subscription::Schedule' );
	use_ok( 'Net::API::Stripe::Billing::Subscription' );
	use_ok( 'Net::API::Stripe::Billing::TaxID' );
	use_ok( 'Net::API::Stripe::Billing::Thresholds' );
	use_ok( 'Net::API::Stripe::Billing::UsageRecord' );
	use_ok( 'Net::API::Stripe::Bitcoin::Transaction' );
	use_ok( 'Net::API::Stripe::Charge::List' );
	use_ok( 'Net::API::Stripe::Charge::Outcome' );
	use_ok( 'Net::API::Stripe::Charge::Refunds' );
	use_ok( 'Net::API::Stripe::Charge' );
	use_ok( 'Net::API::Stripe::Checkout::Item' );
	use_ok( 'Net::API::Stripe::Checkout::Session' );
	use_ok( 'Net::API::Stripe::Connect::Account::Branding' );
	use_ok( 'Net::API::Stripe::Connect::Account::Capability' );
	use_ok( 'Net::API::Stripe::Connect::Account::Company' );
	use_ok( 'Net::API::Stripe::Connect::Account::Document' );
	use_ok( 'Net::API::Stripe::Connect::Account::ExternalAccounts' );
	use_ok( 'Net::API::Stripe::Connect::Account::Link' );
	use_ok( 'Net::API::Stripe::Connect::Account::LoginLink' );
	use_ok( 'Net::API::Stripe::Connect::Account::Relationship' );
	use_ok( 'Net::API::Stripe::Connect::Account::Requirements' );
	use_ok( 'Net::API::Stripe::Connect::Account::Settings::CardPayments' );
	use_ok( 'Net::API::Stripe::Connect::Account::Settings::Dashboard' );
	use_ok( 'Net::API::Stripe::Connect::Account::Settings::Payments' );
	use_ok( 'Net::API::Stripe::Connect::Account::Settings::Payouts' );
	use_ok( 'Net::API::Stripe::Connect::Account::Settings' );
	use_ok( 'Net::API::Stripe::Connect::Account::TosAcceptance' );
	use_ok( 'Net::API::Stripe::Connect::Account::Verification' );
	use_ok( 'Net::API::Stripe::Connect::Account' );
	use_ok( 'Net::API::Stripe::Connect::ApplicationFee::Refund' );
	use_ok( 'Net::API::Stripe::Connect::ApplicationFee::Refunds' );
	use_ok( 'Net::API::Stripe::Connect::ApplicationFee' );
	use_ok( 'Net::API::Stripe::Connect::Business::Profile' );
	use_ok( 'Net::API::Stripe::Connect::CountrySpec::VerificationFields::Details' );
	use_ok( 'Net::API::Stripe::Connect::CountrySpec::VerificationFields' );
	use_ok( 'Net::API::Stripe::Connect::CountrySpec' );
	use_ok( 'Net::API::Stripe::Connect::ExternalAccount::Bank' );
	use_ok( 'Net::API::Stripe::Connect::ExternalAccount::Card' );
	use_ok( 'Net::API::Stripe::Connect::Person' );
	use_ok( 'Net::API::Stripe::Connect::TopUp' );
	use_ok( 'Net::API::Stripe::Connect::Transfer::Reversal' );
	use_ok( 'Net::API::Stripe::Connect::Transfer::Reversals' );
	use_ok( 'Net::API::Stripe::Connect::Transfer' );
	use_ok( 'Net::API::Stripe::Customer::BalanceTransaction' );
	use_ok( 'Net::API::Stripe::Customer::List' );
	use_ok( 'Net::API::Stripe::Customer::Sources' );
	use_ok( 'Net::API::Stripe::Customer::TaxId' );
	use_ok( 'Net::API::Stripe::Customer::TaxIds' );
	use_ok( 'Net::API::Stripe::Customer::TaxInfo' );
	use_ok( 'Net::API::Stripe::Customer::TaxInfoVerification' );
	use_ok( 'Net::API::Stripe::Customer' );
	use_ok( 'Net::API::Stripe::CustomField' );
	use_ok( 'Net::API::Stripe::Dispute::Evidence' );
	use_ok( 'Net::API::Stripe::Dispute::EvidenceDetails' );
	use_ok( 'Net::API::Stripe::Dispute' );
	use_ok( 'Net::API::Stripe::Error' );
	use_ok( 'Net::API::Stripe::Event::Data' );
	use_ok( 'Net::API::Stripe::Event::Request' );
	use_ok( 'Net::API::Stripe::Event' );
	use_ok( 'Net::API::Stripe::File::Link' );
	use_ok( 'Net::API::Stripe::File::Links' );
	use_ok( 'Net::API::Stripe::File' );
	use_ok( 'Net::API::Stripe::Fraud::Review::Session' );
	use_ok( 'Net::API::Stripe::Fraud::Review' );
	use_ok( 'Net::API::Stripe::Fraud::ValueList::Item' );
	use_ok( 'Net::API::Stripe::Fraud::ValueList' );
	use_ok( 'Net::API::Stripe::Fraud' );
	use_ok( 'Net::API::Stripe::Generic' );
	use_ok( 'Net::API::Stripe::GeoLocation' );
	use_ok( 'Net::API::Stripe::Issuing::Authorization::RequestHistory' );
	use_ok( 'Net::API::Stripe::Issuing::Authorization::Transaction' );
	use_ok( 'Net::API::Stripe::Issuing::Authorization::VerificationData' );
	use_ok( 'Net::API::Stripe::Issuing::Authorization' );
	use_ok( 'Net::API::Stripe::Issuing::Card::AuthorizationsControl::SpendingLimit' );
	use_ok( 'Net::API::Stripe::Issuing::Card::AuthorizationsControl' );
	use_ok( 'Net::API::Stripe::Issuing::Card::Holder' );
	use_ok( 'Net::API::Stripe::Issuing::Card' );
	use_ok( 'Net::API::Stripe::Issuing::Dispute::Evidence::Fraudulent' );
	use_ok( 'Net::API::Stripe::Issuing::Dispute::Evidence::Other' );
	use_ok( 'Net::API::Stripe::Issuing::Dispute::Evidence' );
	use_ok( 'Net::API::Stripe::Issuing::Dispute' );
	use_ok( 'Net::API::Stripe::Issuing::MerchantData' );
	use_ok( 'Net::API::Stripe::Issuing::Transaction' );
	use_ok( 'Net::API::Stripe::List' );
	use_ok( 'Net::API::Stripe::Mandate' );
	use_ok( 'Net::API::Stripe::Number' );
	use_ok( 'Net::API::Stripe::Order::DeliveryEstimate' );
	use_ok( 'Net::API::Stripe::Order::Item' );
	use_ok( 'Net::API::Stripe::Order::Return' );
	use_ok( 'Net::API::Stripe::Order::Returns' );
	use_ok( 'Net::API::Stripe::Order::ShippingMethod' );
	use_ok( 'Net::API::Stripe::Order::SKU::Inventory' );
	use_ok( 'Net::API::Stripe::Order::SKU::PackageDimensions' );
	use_ok( 'Net::API::Stripe::Order::SKU' );
	use_ok( 'Net::API::Stripe::Order::StatusTransitions' );
	use_ok( 'Net::API::Stripe::Order' );
	use_ok( 'Net::API::Stripe::Payment::BankAccount' );
	use_ok( 'Net::API::Stripe::Payment::Card::List' );
	use_ok( 'Net::API::Stripe::Payment::Card' );
	use_ok( 'Net::API::Stripe::Payment::GeneratedFrom' );
	use_ok( 'Net::API::Stripe::Payment::Installment' );
	use_ok( 'Net::API::Stripe::Payment::Intent::Charges' );
	use_ok( 'Net::API::Stripe::Payment::Intent::NextAction' );
	use_ok( 'Net::API::Stripe::Payment::Intent::Setup' );
	use_ok( 'Net::API::Stripe::Payment::Intent::TransferData' );
	use_ok( 'Net::API::Stripe::Payment::Intent' );
	use_ok( 'Net::API::Stripe::Payment::Method::Details' );
	use_ok( 'Net::API::Stripe::Payment::Method' );
	use_ok( 'Net::API::Stripe::Payment::Source::ACHCreditTransfer' );
	use_ok( 'Net::API::Stripe::Payment::Source::ACHDebit' );
	use_ok( 'Net::API::Stripe::Payment::Source::CodeVerification' );
	use_ok( 'Net::API::Stripe::Payment::Source::Owner' );
	use_ok( 'Net::API::Stripe::Payment::Source::Receiver' );
	use_ok( 'Net::API::Stripe::Payment::Source::Redirect' );
	use_ok( 'Net::API::Stripe::Payment::Source' );
	use_ok( 'Net::API::Stripe::Payout' );
	use_ok( 'Net::API::Stripe::Product::PackageDimension' );
	use_ok( 'Net::API::Stripe::Product' );
	use_ok( 'Net::API::Stripe::Refund' );
	use_ok( 'Net::API::Stripe::Reporting::ReportRun' );
	use_ok( 'Net::API::Stripe::Shipping' );
	use_ok( 'Net::API::Stripe::Sigma::ScheduledQueryRun' );
	use_ok( 'Net::API::Stripe::Tax::Rate' );
	use_ok( 'Net::API::Stripe::Terminal::ConnectionToken' );
	use_ok( 'Net::API::Stripe::Terminal::Location' );
	use_ok( 'Net::API::Stripe::Terminal::Reader' );
	use_ok( 'Net::API::Stripe::TimeZone' );
	use_ok( 'Net::API::Stripe::Token' );
}

## my $object = Net::API::Stripe->new ();
## isa_ok ($object, 'Net::API::Stripe');


