# -*- perl -*-

use Test::Pod tests => 156;

pod_file_ok( './lib/Net/API/Stripe/Address.pm' );
pod_file_ok( './lib/Net/API/Stripe/AddressKana.pm' );
pod_file_ok( './lib/Net/API/Stripe/AddressKanji.pm' );
pod_file_ok( './lib/Net/API/Stripe/Balance/ConnectReserved.pm' );
pod_file_ok( './lib/Net/API/Stripe/Balance/Pending.pm' );
pod_file_ok( './lib/Net/API/Stripe/Balance/Transaction/FeeDetails.pm' );
pod_file_ok( './lib/Net/API/Stripe/Balance/Transaction.pm' );
pod_file_ok( './lib/Net/API/Stripe/Balance.pm' );
pod_file_ok( './lib/Net/API/Stripe/Billing/Coupon.pm' );
pod_file_ok( './lib/Net/API/Stripe/Billing/CreditNote/LineItem.pm' );
pod_file_ok( './lib/Net/API/Stripe/Billing/CreditNote.pm' );
pod_file_ok( './lib/Net/API/Stripe/Billing/Details.pm' );
pod_file_ok( './lib/Net/API/Stripe/Billing/Discount.pm' );
pod_file_ok( './lib/Net/API/Stripe/Billing/Invoice/BalanceSettings.pm' );
pod_file_ok( './lib/Net/API/Stripe/Billing/Invoice/Item.pm' );
pod_file_ok( './lib/Net/API/Stripe/Billing/Invoice/LineItem.pm' );
pod_file_ok( './lib/Net/API/Stripe/Billing/Invoice/Lines.pm' );
pod_file_ok( './lib/Net/API/Stripe/Billing/Invoice/Period.pm' );
pod_file_ok( './lib/Net/API/Stripe/Billing/Invoice/Settings.pm' );
pod_file_ok( './lib/Net/API/Stripe/Billing/Invoice/StatusTransition.pm' );
pod_file_ok( './lib/Net/API/Stripe/Billing/Invoice/TaxAmount.pm' );
pod_file_ok( './lib/Net/API/Stripe/Billing/Invoice.pm' );
pod_file_ok( './lib/Net/API/Stripe/Billing/Plan/Tiers.pm' );
pod_file_ok( './lib/Net/API/Stripe/Billing/Plan/TransformUsage.pm' );
pod_file_ok( './lib/Net/API/Stripe/Billing/Plan.pm' );
pod_file_ok( './lib/Net/API/Stripe/Billing/Subscription/Item.pm' );
pod_file_ok( './lib/Net/API/Stripe/Billing/Subscription/Items.pm' );
pod_file_ok( './lib/Net/API/Stripe/Billing/Subscription/Schedule.pm' );
pod_file_ok( './lib/Net/API/Stripe/Billing/Subscription.pm' );
pod_file_ok( './lib/Net/API/Stripe/Billing/TaxID.pm' );
pod_file_ok( './lib/Net/API/Stripe/Billing/Thresholds.pm' );
pod_file_ok( './lib/Net/API/Stripe/Billing/UsageRecord.pm' );
pod_file_ok( './lib/Net/API/Stripe/Bitcoin/Transaction.pm' );
pod_file_ok( './lib/Net/API/Stripe/Charge/List.pm' );
pod_file_ok( './lib/Net/API/Stripe/Charge/Outcome.pm' );
pod_file_ok( './lib/Net/API/Stripe/Charge/Refunds.pm' );
pod_file_ok( './lib/Net/API/Stripe/Charge.pm' );
pod_file_ok( './lib/Net/API/Stripe/Checkout/Item.pm' );
pod_file_ok( './lib/Net/API/Stripe/Checkout/Session.pm' );
pod_file_ok( './lib/Net/API/Stripe/Connect/Account/Branding.pm' );
pod_file_ok( './lib/Net/API/Stripe/Connect/Account/Capability.pm' );
pod_file_ok( './lib/Net/API/Stripe/Connect/Account/Company.pm' );
pod_file_ok( './lib/Net/API/Stripe/Connect/Account/Document.pm' );
pod_file_ok( './lib/Net/API/Stripe/Connect/Account/ExternalAccounts.pm' );
pod_file_ok( './lib/Net/API/Stripe/Connect/Account/Link.pm' );
pod_file_ok( './lib/Net/API/Stripe/Connect/Account/LoginLink.pm' );
pod_file_ok( './lib/Net/API/Stripe/Connect/Account/Relationship.pm' );
pod_file_ok( './lib/Net/API/Stripe/Connect/Account/Requirements.pm' );
pod_file_ok( './lib/Net/API/Stripe/Connect/Account/Settings/CardPayments.pm' );
pod_file_ok( './lib/Net/API/Stripe/Connect/Account/Settings/Dashboard.pm' );
pod_file_ok( './lib/Net/API/Stripe/Connect/Account/Settings/Payments.pm' );
pod_file_ok( './lib/Net/API/Stripe/Connect/Account/Settings/Payouts.pm' );
pod_file_ok( './lib/Net/API/Stripe/Connect/Account/Settings.pm' );
pod_file_ok( './lib/Net/API/Stripe/Connect/Account/TosAcceptance.pm' );
pod_file_ok( './lib/Net/API/Stripe/Connect/Account/Verification.pm' );
pod_file_ok( './lib/Net/API/Stripe/Connect/Account.pm' );
pod_file_ok( './lib/Net/API/Stripe/Connect/ApplicationFee/Refund.pm' );
pod_file_ok( './lib/Net/API/Stripe/Connect/ApplicationFee/Refunds.pm' );
pod_file_ok( './lib/Net/API/Stripe/Connect/ApplicationFee.pm' );
pod_file_ok( './lib/Net/API/Stripe/Connect/Business/Profile.pm' );
pod_file_ok( './lib/Net/API/Stripe/Connect/CountrySpec/VerificationFields/Details.pm' );
pod_file_ok( './lib/Net/API/Stripe/Connect/CountrySpec/VerificationFields.pm' );
pod_file_ok( './lib/Net/API/Stripe/Connect/CountrySpec.pm' );
pod_file_ok( './lib/Net/API/Stripe/Connect/ExternalAccount/Bank.pm' );
pod_file_ok( './lib/Net/API/Stripe/Connect/ExternalAccount/Card.pm' );
pod_file_ok( './lib/Net/API/Stripe/Connect/Person.pm' );
pod_file_ok( './lib/Net/API/Stripe/Connect/TopUp.pm' );
pod_file_ok( './lib/Net/API/Stripe/Connect/Transfer/Reversal.pm' );
pod_file_ok( './lib/Net/API/Stripe/Connect/Transfer/Reversals.pm' );
pod_file_ok( './lib/Net/API/Stripe/Connect/Transfer.pm' );
pod_file_ok( './lib/Net/API/Stripe/Customer/BalanceTransaction.pm' );
pod_file_ok( './lib/Net/API/Stripe/Customer/List.pm' );
pod_file_ok( './lib/Net/API/Stripe/Customer/Sources.pm' );
pod_file_ok( './lib/Net/API/Stripe/Customer/TaxId.pm' );
pod_file_ok( './lib/Net/API/Stripe/Customer/TaxIds.pm' );
pod_file_ok( './lib/Net/API/Stripe/Customer/TaxInfo.pm' );
pod_file_ok( './lib/Net/API/Stripe/Customer/TaxInfoVerification.pm' );
pod_file_ok( './lib/Net/API/Stripe/Customer.pm' );
pod_file_ok( './lib/Net/API/Stripe/CustomField.pm' );
pod_file_ok( './lib/Net/API/Stripe/Dispute/Evidence.pm' );
pod_file_ok( './lib/Net/API/Stripe/Dispute/EvidenceDetails.pm' );
pod_file_ok( './lib/Net/API/Stripe/Dispute.pm' );
pod_file_ok( './lib/Net/API/Stripe/Error.pm' );
pod_file_ok( './lib/Net/API/Stripe/Event/Data.pm' );
pod_file_ok( './lib/Net/API/Stripe/Event/Request.pm' );
pod_file_ok( './lib/Net/API/Stripe/Event.pm' );
pod_file_ok( './lib/Net/API/Stripe/File/Link.pm' );
pod_file_ok( './lib/Net/API/Stripe/File/Links.pm' );
pod_file_ok( './lib/Net/API/Stripe/File.pm' );
pod_file_ok( './lib/Net/API/Stripe/Fraud/Review/Session.pm' );
pod_file_ok( './lib/Net/API/Stripe/Fraud/Review.pm' );
pod_file_ok( './lib/Net/API/Stripe/Fraud/ValueList/Item.pm' );
pod_file_ok( './lib/Net/API/Stripe/Fraud/ValueList.pm' );
pod_file_ok( './lib/Net/API/Stripe/Fraud.pm' );
pod_file_ok( './lib/Net/API/Stripe/Generic.pm' );
pod_file_ok( './lib/Net/API/Stripe/GeoLocation.pm' );
pod_file_ok( './lib/Net/API/Stripe/Issuing/Authorization/RequestHistory.pm' );
pod_file_ok( './lib/Net/API/Stripe/Issuing/Authorization/Transaction.pm' );
pod_file_ok( './lib/Net/API/Stripe/Issuing/Authorization/VerificationData.pm' );
pod_file_ok( './lib/Net/API/Stripe/Issuing/Authorization.pm' );
pod_file_ok( './lib/Net/API/Stripe/Issuing/Card/AuthorizationsControl/SpendingLimit.pm' );
pod_file_ok( './lib/Net/API/Stripe/Issuing/Card/AuthorizationsControl.pm' );
pod_file_ok( './lib/Net/API/Stripe/Issuing/Card/Holder.pm' );
pod_file_ok( './lib/Net/API/Stripe/Issuing/Card.pm' );
pod_file_ok( './lib/Net/API/Stripe/Issuing/Dispute/Evidence/Fraudulent.pm' );
pod_file_ok( './lib/Net/API/Stripe/Issuing/Dispute/Evidence/Other.pm' );
pod_file_ok( './lib/Net/API/Stripe/Issuing/Dispute/Evidence.pm' );
pod_file_ok( './lib/Net/API/Stripe/Issuing/Dispute.pm' );
pod_file_ok( './lib/Net/API/Stripe/Issuing/MerchantData.pm' );
pod_file_ok( './lib/Net/API/Stripe/Issuing/Transaction.pm' );
pod_file_ok( './lib/Net/API/Stripe/List.pm' );
pod_file_ok( './lib/Net/API/Stripe/Mandate.pm' );
pod_file_ok( './lib/Net/API/Stripe/Order/DeliveryEstimate.pm' );
pod_file_ok( './lib/Net/API/Stripe/Order/Item.pm' );
pod_file_ok( './lib/Net/API/Stripe/Order/Return.pm' );
pod_file_ok( './lib/Net/API/Stripe/Order/Returns.pm' );
pod_file_ok( './lib/Net/API/Stripe/Order/ShippingMethod.pm' );
pod_file_ok( './lib/Net/API/Stripe/Order/SKU/Inventory.pm' );
pod_file_ok( './lib/Net/API/Stripe/Order/SKU/PackageDimensions.pm' );
pod_file_ok( './lib/Net/API/Stripe/Order/SKU.pm' );
pod_file_ok( './lib/Net/API/Stripe/Order/StatusTransitions.pm' );
pod_file_ok( './lib/Net/API/Stripe/Order.pm' );
pod_file_ok( './lib/Net/API/Stripe/Payment/BankAccount.pm' );
pod_file_ok( './lib/Net/API/Stripe/Payment/Card/List.pm' );
pod_file_ok( './lib/Net/API/Stripe/Payment/Card.pm' );
pod_file_ok( './lib/Net/API/Stripe/Payment/GeneratedFrom.pm' );
pod_file_ok( './lib/Net/API/Stripe/Payment/Installment.pm' );
pod_file_ok( './lib/Net/API/Stripe/Payment/Intent/Charges.pm' );
pod_file_ok( './lib/Net/API/Stripe/Payment/Intent/NextAction.pm' );
pod_file_ok( './lib/Net/API/Stripe/Payment/Intent/Setup.pm' );
pod_file_ok( './lib/Net/API/Stripe/Payment/Intent/TransferData.pm' );
pod_file_ok( './lib/Net/API/Stripe/Payment/Intent.pm' );
pod_file_ok( './lib/Net/API/Stripe/Payment/Method/Details.pm' );
pod_file_ok( './lib/Net/API/Stripe/Payment/Method.pm' );
pod_file_ok( './lib/Net/API/Stripe/Payment/Source/ACHCreditTransfer.pm' );
pod_file_ok( './lib/Net/API/Stripe/Payment/Source/ACHDebit.pm' );
pod_file_ok( './lib/Net/API/Stripe/Payment/Source/CodeVerification.pm' );
pod_file_ok( './lib/Net/API/Stripe/Payment/Source/Owner.pm' );
pod_file_ok( './lib/Net/API/Stripe/Payment/Source/Receiver.pm' );
pod_file_ok( './lib/Net/API/Stripe/Payment/Source/Redirect.pm' );
pod_file_ok( './lib/Net/API/Stripe/Payment/Source.pm' );
pod_file_ok( './lib/Net/API/Stripe/Payout.pm' );
pod_file_ok( './lib/Net/API/Stripe/Product/PackageDimension.pm' );
pod_file_ok( './lib/Net/API/Stripe/Product.pm' );
pod_file_ok( './lib/Net/API/Stripe/Refund.pm' );
pod_file_ok( './lib/Net/API/Stripe/Reporting/ReportRun.pm' );
pod_file_ok( './lib/Net/API/Stripe/Shipping.pm' );
pod_file_ok( './lib/Net/API/Stripe/Sigma/ScheduledQueryRun.pm' );
pod_file_ok( './lib/Net/API/Stripe/Tax/Rate.pm' );
pod_file_ok( './lib/Net/API/Stripe/Terminal/ConnectionToken.pm' );
pod_file_ok( './lib/Net/API/Stripe/Terminal/Location.pm' );
pod_file_ok( './lib/Net/API/Stripe/Terminal/Reader.pm' );
pod_file_ok( './lib/Net/API/Stripe/TimeZone.pm' );
pod_file_ok( './lib/Net/API/Stripe/Token.pm' );
pod_file_ok( './lib/Net/API/Stripe/WebHook/Object.pm' );
pod_file_ok( './lib/Net/API/Stripe.pm' );
